@@ -2,8 +2,8 @@
 ;; Copyright (C) 2020-2023 Simon Nicolussi
 
 ;; Author: Simon Nicolussi <sinic@sinic.name>
-;; Package-Version: 0.2
-;; Package-Revision: 6fdb2da55804
+;; Package-Version: 20251104.1820
+;; Package-Revision: 638d73e7c3fe
 ;; Package-Requires: ((emacs "26.1"))
 ;; Keywords: unix
 ;; Homepage: https://github.com/sinic/ednc
@@ -55,6 +55,22 @@
 
 (defgroup ednc () "Emacs Desktop Notification Center." :group 'unix)
 
+(defface ednc-app-name nil
+  "Name of the application that sent the notification.")
+
+(defface ednc-title nil
+  "Notification title.")
+
+(defface ednc-body nil
+  "Notification text.")
+
+(defface ednc-dismissed '((t (:strike-through t)))
+  "Default face for dismissed notifications.")
+
+(defcustom ednc-dismissed-face 'ednc-dismissed
+  "Face to be used for dismissed notifications."
+  :type 'face)
+
 ;;;###autoload
 (define-minor-mode ednc-mode
   "Act as a Desktop Notifications server and track notifications."
@@ -164,10 +180,13 @@ If EXPAND-FLAG is nil, make details invisible by default."
     (format (propertize " %s[%s: %s]%s" 'face (list :inherit inherit)
                         'ednc-notification notification)
             (alist-get 'icon (ednc-notification-amendments notification) "")
-            (ednc-notification-app-name notification)
-            (ednc--format-summary notification)
+            (propertize (ednc-notification-app-name notification)
+                        'face 'ednc-app-name)
+            (propertize (ednc--format-summary notification)
+                        'face 'ednc-title)
             (propertize (concat "\n" (ednc-notification-body notification) "\n")
-                        'invisible (not expand-flag)))))
+                        'invisible (not expand-flag)
+                        'face 'ednc-body))))
 
 (defun ednc--format-summary (notification)
   "Return propertized summary of NOTIFICATION."
@@ -294,10 +313,11 @@ This function modifies the notification's hints."
                 (ednc--path-to-image (ednc-notification-app-icon new))
                 (ednc--data-to-image (ednc--get-hint hints "icon_data" t)))))
       (when image
-        (setf (image-property image :max-height) (frame-char-height)
-              (image-property image :ascent) 90)
-        (push (cons 'icon (with-temp-buffer (insert-image image)
-                                            (buffer-string)))
+        (setf (image-property image :max-height) '(1.0 . ch)
+              (image-property image :scale) 1.0
+              (image-property image :mask) 'heuristic
+              (image-property image :ascent) 'center)
+        (push (cons 'icon (propertize " " 'display image))
                     (ednc-notification-amendments new))))))
 
 (defun ednc--get-hint (hints key &optional remove-flag)
@@ -381,11 +401,11 @@ This function is destructive."
   "Remove OLD notification from its log buffer, if it exists."
   (cl-destructuring-bind (buffer . position)
       (alist-get 'logged (ednc-notification-amendments old) '(nil))
-    (when (buffer-live-p buffer)
+    (when (and (buffer-live-p buffer) ednc-dismissed-face)
       (with-current-buffer buffer
         (save-excursion
           (add-text-properties (goto-char position) (line-end-position)
-                               '(face (:strike-through t))))))))
+                               `(face ,ednc-dismissed-face)))))))
 
 (defun ednc--append-new-notification-to-log-buffer (new)
   "Append NEW notification to log buffer."
